==> devops-client-java-1.0.2-sources.jar: io/alauda/devops/java/client/models/V1alpha1JenkinsAgentFluentImpl.java <==
package io.alauda.devops.java.client.models;

import java.lang.StringBuffer;
import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.alauda.devops.java.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class V1alpha1JenkinsAgentFluentImpl<A extends V1alpha1JenkinsAgentFluent<A>> extends io.alauda.devops.java.client.fluent.BaseFluent<A> implements V1alpha1JenkinsAgentFluent<A>{

    private String label;
    private String raw;

    public V1alpha1JenkinsAgentFluentImpl(){
    }
    public V1alpha1JenkinsAgentFluentImpl(V1alpha1JenkinsAgent instance){
            this.withLabel(instance.getLabel());

            this.withRaw(instance.getRaw());

    }

    public String getLabel(){
            return this.label;
    }

    public A withLabel(String label){
            this.label=label; return (A) this;
    }

    public Boolean hasLabel(){
            return this.label != null;
    }

    public A withNewLabel(String arg1){
            return (A)withLabel(new String(arg1));
    }

    public A withNewLabel(StringBuilder arg1){
            return (A)withLabel(new String(arg1));
    }

    public A withNewLabel(StringBuffer arg1){
            return (A)withLabel(new String(arg1));
    }

    public String getRaw(){
            return this.raw;
    }

    public A withRaw(String raw){
            this.raw=raw; return (A) this;
    }

    public Boolean hasRaw(){
            return this.raw != null;
    }

    public A withNewRaw(String arg1){
            return (A)withRaw(new String(arg1));
    }

    public A withNewRaw(StringBuilder arg1){
            return (A)withRaw(new String(arg1));
    }

    public A withNewRaw(StringBuffer arg1){
            return (A)withRaw(new String(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1alpha1JenkinsAgentFluentImpl that = (V1alpha1JenkinsAgentFluentImpl) o;
            if (label != null ? !label.equals(that.label) :that.label != null) return false;
            if (raw != null ? !raw.equals(that.raw) :that.raw != null) return false;
            return true;
    }




}

==> devops-client-java-1.0.6-sources.jar: io/alauda/devops/java/client/models/V1alpha1JenkinsAgentFluentImpl.java <==
package io.alauda.devops.java.client.models;

import java.lang.StringBuffer;
import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.alauda.devops.java.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class V1alpha1JenkinsAgentFluentImpl<A extends V1alpha1JenkinsAgentFluent<A>> extends io.alauda.devops.java.client.fluent.BaseFluent<A> implements V1alpha1JenkinsAgentFluent<A>{

    private String label;
    private String labelMatcher;
    private String raw;

    public V1alpha1JenkinsAgentFluentImpl(){
    }
    public V1alpha1JenkinsAgentFluentImpl(V1alpha1JenkinsAgent instance){
            this.withLabel(instance.getLabel());

            this.withLabelMatcher(instance.getLabelMatcher());

            this.withRaw(instance.getRaw());

    }

    public String getLabel(){
            return this.label;
    }

    public A withLabel(String label){
            this.label=label; return (A) this;
    }

    public Boolean hasLabel(){
            return this.label != null;
    }

    public A withNewLabel(String arg1){
            return (A)withLabel(new String(arg1));
    }

    public A withNewLabel(StringBuilder arg1){
            return (A)withLabel(new String(arg1));
    }

    public A withNewLabel(StringBuffer arg1){
            return (A)withLabel(new String(arg1));
    }

    public String getLabelMatcher(){
            return this.labelMatcher;
    }

    public A withLabelMatcher(String labelMatcher){
            this.labelMatcher=labelMatcher; return (A) this;
    }

    public Boolean hasLabelMatcher(){
            return this.labelMatcher != null;
    }

    public A withNewLabelMatcher(String arg1){
            return (A)withLabelMatcher(new String(arg1));
    }

    public A withNewLabelMatcher(StringBuilder arg1){
            return (A)withLabelMatcher(new String(arg1));
    }

    public A withNewLabelMatcher(StringBuffer arg1){
            return (A)withLabelMatcher(new String(arg1));
    }

    public String getRaw(){
            return this.raw;
    }

    public A withRaw(String raw){
            this.raw=raw; return (A) this;
    }

    public Boolean hasRaw(){
            return this.raw != null;
    }

    public A withNewRaw(String arg1){
            return (A)withRaw(new String(arg1));
    }

    public A withNewRaw(StringBuilder arg1){
            return (A)withRaw(new String(arg1));
    }

    public A withNewRaw(StringBuffer arg1){
            return (A)withRaw(new String(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1alpha1JenkinsAgentFluentImpl that = (V1alpha1JenkinsAgentFluentImpl) o;
            if (label != null ? !label.equals(that.label) :that.label != null) return false;
            if (labelMatcher != null ? !labelMatcher.equals(that.labelMatcher) :that.labelMatcher != null) return false;
            if (raw != null ? !raw.equals(that.raw) :that.raw != null) return false;
            return true;
    }




}
